@@ -51,6 +51,7 @@ extern "C" {
 #define INI_PORT			"Port"	/* Port on which the
 						 * Postmaster is listening */
 #define INI_DATABASE			"Database"	/* Database Name */
+#define ABBR_DATABASE			"DX"	/* Database Name */
 #define INI_UID				"UID"		/* Default User Name */
 #define INI_USERNAME			"Username"	/* Default User Name */
 #define INI_PASSWORD			"Password"	/* Default Password */
@@ -147,6 +148,7 @@ extern "C" {
 #define INI_TRUEISMINUS1		"TrueIsMinus1"
 #define ABBR_TRUEISMINUS1		"C6"
 #define INI_INT8AS			"BI"
+#define INI_NUMERIC_AS			"D6"
 #define INI_BYTEAASLONGVARBINARY	"ByteaAsLongVarBinary"
 #define ABBR_BYTEAASLONGVARBINARY	"C7"
 #define INI_USESERVERSIDEPREPARE	"UseServerSidePrepare"
@@ -259,6 +261,7 @@ extern "C" {
 #define DEFAULT_USESERVERSIDEPREPARE	1
 #define DEFAULT_LOWERCASEIDENTIFIER	0
 #define DEFAULT_SSLMODE			SSLMODE_DISABLE
+#define DEFAULT_NUMERIC_AS		(-101)
 
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 #define DEFAULT_XAOPT			1
@@ -314,6 +317,7 @@ UInt4	getExtraOptions(const ConnInfo *);
 BOOL	setExtraOptions(ConnInfo *, const char *str, const char *format);
 char	*extract_extra_attribute_setting(const pgNAME setting, const char *attr);
 signed char	ci_updatable_cursors_set(ConnInfo *ci);
+void		getCiAllDefaults(ConnInfo *ci);
 
 #ifdef	__cplusplus
 }
