@@ -154,6 +154,8 @@ typedef	UInt4	OID;
 #define SQL_FALSE FALSE
 #endif /* SQL_FALSE */
 
+#define	FORMAT_SMALLI	"%d"	/* SQLSMALLINT */
+#define	FORMAT_USMALLI	"%u"	/* SQLUSMALLINT */
 #ifdef	WIN32
 #ifndef	SSIZE_T_DEFINED
 #define	ssize_t	SSIZE_T
@@ -614,6 +616,8 @@ typedef struct
 	char		translation_dll[MEDIUM_REGISTRY_LEN];
 	char		translation_option[SMALL_REGISTRY_LEN];
 	char		password_required;
+	char		conn_settings_in_str;
+	char		pqopt_in_str;
 	pgNAME		conn_settings;
 	pgNAME		pqopt;
 	signed char	allow_keyset;
@@ -633,6 +637,7 @@ typedef struct
 	signed char	ignore_round_trip_time;
 	signed char	disable_keepalive;
 	signed char	wcs_debug;
+	signed char	numeric_as;
 	UInt4		extra_opts;
 	Int4		keepalive_idle;
 	Int4		keepalive_interval;
